=============================
ytrie
=============================

.. image:: https://badge.fury.io/py/ytrie.png
    :target: http://badge.fury.io/py/ytrie

.. image:: https://travis-ci.org/ashwinjv/ytrie.png?branch=master
    :target: https://travis-ci.org/ashwinjv/ytrie

.. image:: https://pypip.in/d/ytrie/badge.png
    :target: https://pypi.python.org/pypi/ytrie


A pure python API for Trie data access


Features
--------

* TODO

